@@ -295,8 +295,14 @@ class Arc1(Arc):
 
         # Get the properties inherited from Arc
         Arc1_dict = super(Arc1, self).as_dict()
-        Arc1_dict["begin"] = self.begin
-        Arc1_dict["end"] = self.end
+        if self.begin is None:
+            Arc1_dict["begin"] = None
+        else:
+            Arc1_dict["begin"] = str(self.begin)
+        if self.end is None:
+            Arc1_dict["end"] = None
+        else:
+            Arc1_dict["end"] = str(self.end)
         Arc1_dict["radius"] = self.radius
         Arc1_dict["is_trigo_direction"] = self.is_trigo_direction
         # The class name is added to the dict for deserialisation purpose
@@ -320,6 +326,8 @@ class Arc1(Arc):
 
     def _set_begin(self, value):
         """setter of begin"""
+        if isinstance(value, str):
+            value = complex(value)
         check_var("begin", value, "complex")
         self._begin = value
 
@@ -338,6 +346,8 @@ class Arc1(Arc):
 
     def _set_end(self, value):
         """setter of end"""
+        if isinstance(value, str):
+            value = complex(value)
         check_var("end", value, "complex")
         self._end = value
 
