@@ -26,11 +26,6 @@ try:
 except ImportError as error:
     run = error
 
-try:
-    from ..Methods.Simulation.Force.get_axes import get_axes
-except ImportError as error:
-    get_axes = error
-
 
 from ._check import InitUnKnowClassError
 
@@ -61,15 +56,6 @@ class Force(FrozenClass):
         )
     else:
         run = run
-    # cf Methods.Simulation.Force.get_axes
-    if isinstance(get_axes, ImportError):
-        get_axes = property(
-            fget=lambda x: raise_(
-                ImportError("Can't use Force method get_axes: " + str(get_axes))
-            )
-        )
-    else:
-        get_axes = get_axes
     # save and copy methods are available in all object
     save = save
     copy = copy
@@ -188,7 +174,7 @@ class Force(FrozenClass):
     is_periodicity_t = property(
         fget=_get_is_periodicity_t,
         fset=_set_is_periodicity_t,
-        doc=u"""True to compute only on one time periodicity (use periodicities defined in output.mag.time)
+        doc=u"""True to compute only on one time periodicity (use periodicities defined in output.force.Time)
 
         :Type: bool
         """,
@@ -206,7 +192,7 @@ class Force(FrozenClass):
     is_periodicity_a = property(
         fget=_get_is_periodicity_a,
         fset=_set_is_periodicity_a,
-        doc=u"""True to compute only on one angle periodicity (use periodicities defined in output.mag.angle)
+        doc=u"""True to compute only on one angle periodicity (use periodicities defined in output.force.Angle)
 
         :Type: bool
         """,
