@@ -9,11 +9,16 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
+from ..Functions.copy import copy
+from ..Functions.load import load_init_dict
+from ..Functions.Load.import_class import import_class
 from .OptiSolver import OptiSolver
 
-from inspect import getsource
-from cloudpickle import dumps, loads
+from ntpath import basename
+from os.path import isfile
 from ._check import CheckTypeError
+import numpy as np
+import random
 from ._check import InitUnKnowClassError
 from .OptiProblem import OptiProblem
 from .XOutput import XOutput
@@ -24,15 +29,9 @@ class OptiGenAlg(OptiSolver):
 
     VERSION = 1
 
-    # save method is available in all object
+    # save and copy methods are available in all object
     save = save
-
-    # generic copy method
-    def copy(self):
-        """Return a copy of the class
-        """
-        return type(self)(init_dict=self.as_dict())
-
+    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -54,37 +53,16 @@ class OptiGenAlg(OptiSolver):
     ):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
-            for Matrix, None will initialise the property with an empty Matrix
-            for pyleecan type, None will call the default constructor
-        - __init__ (init_dict = d) d must be a dictionnary with every properties as keys
+            for pyleecan type, -1 will call the default constructor
+        - __init__ (init_dict = d) d must be a dictionnary with property names as keys
         - __init__ (init_str = s) s must be a string
         s is the file path to load
 
         ndarray or list can be given for Vector and Matrix
         object or dict can be given for pyleecan Object"""
 
-        if problem == -1:
-            problem = OptiProblem()
-        if xoutput == -1:
-            xoutput = XOutput()
-        if init_str is not None:  # Initialisation by str
-            from ..Functions.load import load
-
-            assert type(init_str) is str
-            # load the object from a file
-            obj = load(init_str)
-            assert type(obj) is type(self)
-            selector = obj.selector
-            crossover = obj.crossover
-            mutator = obj.mutator
-            p_cross = obj.p_cross
-            p_mutate = obj.p_mutate
-            size_pop = obj.size_pop
-            nb_gen = obj.nb_gen
-            problem = obj.problem
-            xoutput = obj.xoutput
-            logger_name = obj.logger_name
-            is_keep_all_output = obj.is_keep_all_output
+        if init_str is not None:  # Load from a file
+            init_dict = load_init_dict(init_str)[1]
         if init_dict is not None:  # Initialisation by dict
             assert type(init_dict) is dict
             # Overwrite default value with init_dict content
@@ -110,7 +88,7 @@ class OptiGenAlg(OptiSolver):
                 logger_name = init_dict["logger_name"]
             if "is_keep_all_output" in list(init_dict.keys()):
                 is_keep_all_output = init_dict["is_keep_all_output"]
-        # Initialisation by argument
+        # Set the properties (value check and convertion are done in setter)
         self.selector = selector
         self.crossover = crossover
         self.mutator = mutator
@@ -129,29 +107,29 @@ class OptiGenAlg(OptiSolver):
         # add new properties
 
     def __str__(self):
-        """Convert this objet in a readeable string (for print)"""
+        """Convert this object in a readeable string (for print)"""
 
         OptiGenAlg_str = ""
         # Get the properties inherited from OptiSolver
         OptiGenAlg_str += super(OptiGenAlg, self).__str__()
-        if self._selector[1] is None:
-            OptiGenAlg_str += "selector = " + str(self._selector[1])
+        if self._selector_str is not None:
+            OptiGenAlg_str += "selector = " + self._selector_str + linesep
+        elif self._selector_func is not None:
+            OptiGenAlg_str += "selector = " + str(self._selector_func) + linesep
         else:
-            OptiGenAlg_str += (
-                "selector = " + linesep + str(self._selector[1]) + linesep + linesep
-            )
-        if self._crossover[1] is None:
-            OptiGenAlg_str += "crossover = " + str(self._crossover[1])
+            OptiGenAlg_str += "selector = None" + linesep + linesep
+        if self._crossover_str is not None:
+            OptiGenAlg_str += "crossover = " + self._crossover_str + linesep
+        elif self._crossover_func is not None:
+            OptiGenAlg_str += "crossover = " + str(self._crossover_func) + linesep
         else:
-            OptiGenAlg_str += (
-                "crossover = " + linesep + str(self._crossover[1]) + linesep + linesep
-            )
-        if self._mutator[1] is None:
-            OptiGenAlg_str += "mutator = " + str(self._mutator[1])
+            OptiGenAlg_str += "crossover = None" + linesep + linesep
+        if self._mutator_str is not None:
+            OptiGenAlg_str += "mutator = " + self._mutator_str + linesep
+        elif self._mutator_func is not None:
+            OptiGenAlg_str += "mutator = " + str(self._mutator_func) + linesep
         else:
-            OptiGenAlg_str += (
-                "mutator = " + linesep + str(self._mutator[1]) + linesep + linesep
-            )
+            OptiGenAlg_str += "mutator = None" + linesep + linesep
         OptiGenAlg_str += "p_cross = " + str(self.p_cross) + linesep
         OptiGenAlg_str += "p_mutate = " + str(self.p_mutate) + linesep
         OptiGenAlg_str += "size_pop = " + str(self.size_pop) + linesep
@@ -167,11 +145,11 @@ class OptiGenAlg(OptiSolver):
         # Check the properties inherited from OptiSolver
         if not super(OptiGenAlg, self).__eq__(other):
             return False
-        if other.selector != self.selector:
+        if other._selector_str != self._selector_str:
             return False
-        if other.crossover != self.crossover:
+        if other._crossover_str != self._crossover_str:
             return False
-        if other.mutator != self.mutator:
+        if other._mutator_str != self._mutator_str:
             return False
         if other.p_cross != self.p_cross:
             return False
@@ -184,37 +162,27 @@ class OptiGenAlg(OptiSolver):
         return True
 
     def as_dict(self):
-        """Convert this objet in a json seriable dict (can be use in __init__)
-        """
+        """Convert this object in a json seriable dict (can be use in __init__)"""
 
         # Get the properties inherited from OptiSolver
         OptiGenAlg_dict = super(OptiGenAlg, self).as_dict()
-        if self.selector is None:
+        if self._selector_str is not None:
+            OptiGenAlg_dict["selector"] = self._selector_str
+        else:
             OptiGenAlg_dict["selector"] = None
+        if self._crossover_str is not None:
+            OptiGenAlg_dict["crossover"] = self._crossover_str
         else:
-            OptiGenAlg_dict["selector"] = [
-                dumps(self._selector[0]).decode("ISO-8859-2"),
-                self._selector[1],
-            ]
-        if self.crossover is None:
             OptiGenAlg_dict["crossover"] = None
+        if self._mutator_str is not None:
+            OptiGenAlg_dict["mutator"] = self._mutator_str
         else:
-            OptiGenAlg_dict["crossover"] = [
-                dumps(self._crossover[0]).decode("ISO-8859-2"),
-                self._crossover[1],
-            ]
-        if self.mutator is None:
             OptiGenAlg_dict["mutator"] = None
-        else:
-            OptiGenAlg_dict["mutator"] = [
-                dumps(self._mutator[0]).decode("ISO-8859-2"),
-                self._mutator[1],
-            ]
         OptiGenAlg_dict["p_cross"] = self.p_cross
         OptiGenAlg_dict["p_mutate"] = self.p_mutate
         OptiGenAlg_dict["size_pop"] = self.size_pop
         OptiGenAlg_dict["nb_gen"] = self.nb_gen
-        # The class name is added to the dict fordeserialisation purpose
+        # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         OptiGenAlg_dict["__class__"] = "OptiGenAlg"
         return OptiGenAlg_dict
@@ -234,23 +202,28 @@ class OptiGenAlg(OptiSolver):
 
     def _get_selector(self):
         """getter of selector"""
-        return self._selector[0]
+        return self._selector_func
 
     def _set_selector(self, value):
         """setter of selector"""
-        try:
-            check_var("selector", value, "list")
-        except CheckTypeError:
-            check_var("selector", value, "function")
-        if isinstance(value, list):  # Load function from saved dict
-            self._selector = [loads(value[0].encode("ISO-8859-2")), value[1]]
-        elif value is None:
-            self._selector = [None, None]
+        if value is None:
+            self._selector_str = None
+            self._selector_func = None
+        elif isinstance(value, str) and "lambda" in value:
+            self._selector_str = value
+            self._selector_func = eval(value)
+        elif isinstance(value, str) and isfile(value) and value[-3:] == ".py":
+            self._selector_str = value
+            f = open(value, "r")
+            exec(f.read(), globals())
+            self._selector_func = eval(basename(value[:-3]))
         elif callable(value):
-            self._selector = [value, getsource(value)]
+            self._selector_str = None
+            self._selector_func = value
         else:
-            raise TypeError(
-                "Expected function or list from a saved file, got: " + str(type(value))
+            raise CheckTypeError(
+                "For property selector Expected function or str (path to python file or lambda), got: "
+                + str(type(value))
             )
 
     selector = property(
@@ -264,23 +237,28 @@ class OptiGenAlg(OptiSolver):
 
     def _get_crossover(self):
         """getter of crossover"""
-        return self._crossover[0]
+        return self._crossover_func
 
     def _set_crossover(self, value):
         """setter of crossover"""
-        try:
-            check_var("crossover", value, "list")
-        except CheckTypeError:
-            check_var("crossover", value, "function")
-        if isinstance(value, list):  # Load function from saved dict
-            self._crossover = [loads(value[0].encode("ISO-8859-2")), value[1]]
-        elif value is None:
-            self._crossover = [None, None]
+        if value is None:
+            self._crossover_str = None
+            self._crossover_func = None
+        elif isinstance(value, str) and "lambda" in value:
+            self._crossover_str = value
+            self._crossover_func = eval(value)
+        elif isinstance(value, str) and isfile(value) and value[-3:] == ".py":
+            self._crossover_str = value
+            f = open(value, "r")
+            exec(f.read(), globals())
+            self._crossover_func = eval(basename(value[:-3]))
         elif callable(value):
-            self._crossover = [value, getsource(value)]
+            self._crossover_str = None
+            self._crossover_func = value
         else:
-            raise TypeError(
-                "Expected function or list from a saved file, got: " + str(type(value))
+            raise CheckTypeError(
+                "For property crossover Expected function or str (path to python file or lambda), got: "
+                + str(type(value))
             )
 
     crossover = property(
@@ -294,23 +272,28 @@ class OptiGenAlg(OptiSolver):
 
     def _get_mutator(self):
         """getter of mutator"""
-        return self._mutator[0]
+        return self._mutator_func
 
     def _set_mutator(self, value):
         """setter of mutator"""
-        try:
-            check_var("mutator", value, "list")
-        except CheckTypeError:
-            check_var("mutator", value, "function")
-        if isinstance(value, list):  # Load function from saved dict
-            self._mutator = [loads(value[0].encode("ISO-8859-2")), value[1]]
-        elif value is None:
-            self._mutator = [None, None]
+        if value is None:
+            self._mutator_str = None
+            self._mutator_func = None
+        elif isinstance(value, str) and "lambda" in value:
+            self._mutator_str = value
+            self._mutator_func = eval(value)
+        elif isinstance(value, str) and isfile(value) and value[-3:] == ".py":
+            self._mutator_str = value
+            f = open(value, "r")
+            exec(f.read(), globals())
+            self._mutator_func = eval(basename(value[:-3]))
         elif callable(value):
-            self._mutator = [value, getsource(value)]
+            self._mutator_str = None
+            self._mutator_func = value
         else:
-            raise TypeError(
-                "Expected function or list from a saved file, got: " + str(type(value))
+            raise CheckTypeError(
+                "For property mutator Expected function or str (path to python file or lambda), got: "
+                + str(type(value))
             )
 
     mutator = property(
