@@ -77,15 +77,14 @@ class OutElec(FrozenClass):
 
     def __init__(
         self,
-        time=None,
-        angle=None,
+        Time=None,
+        Angle=None,
         Is=None,
         Ir=None,
         angle_rotor=None,
         N0=None,
         angle_rotor_initial=0,
         logger_name="Pyleecan.OutElec",
-        mmf_unit=None,
         Tem_av_ref=None,
         Id_ref=None,
         Iq_ref=None,
@@ -113,10 +112,10 @@ class OutElec(FrozenClass):
         if init_dict is not None:  # Initialisation by dict
             assert type(init_dict) is dict
             # Overwrite default value with init_dict content
-            if "time" in list(init_dict.keys()):
-                time = init_dict["time"]
-            if "angle" in list(init_dict.keys()):
-                angle = init_dict["angle"]
+            if "Time" in list(init_dict.keys()):
+                Time = init_dict["Time"]
+            if "Angle" in list(init_dict.keys()):
+                Angle = init_dict["Angle"]
             if "Is" in list(init_dict.keys()):
                 Is = init_dict["Is"]
             if "Ir" in list(init_dict.keys()):
@@ -129,8 +128,6 @@ class OutElec(FrozenClass):
                 angle_rotor_initial = init_dict["angle_rotor_initial"]
             if "logger_name" in list(init_dict.keys()):
                 logger_name = init_dict["logger_name"]
-            if "mmf_unit" in list(init_dict.keys()):
-                mmf_unit = init_dict["mmf_unit"]
             if "Tem_av_ref" in list(init_dict.keys()):
                 Tem_av_ref = init_dict["Tem_av_ref"]
             if "Id_ref" in list(init_dict.keys()):
@@ -151,15 +148,14 @@ class OutElec(FrozenClass):
                 Us = init_dict["Us"]
         # Set the properties (value check and convertion are done in setter)
         self.parent = None
-        self.time = time
-        self.angle = angle
+        self.Time = Time
+        self.Angle = Angle
         self.Is = Is
         self.Ir = Ir
         self.angle_rotor = angle_rotor
         self.N0 = N0
         self.angle_rotor_initial = angle_rotor_initial
         self.logger_name = logger_name
-        self.mmf_unit = mmf_unit
         self.Tem_av_ref = Tem_av_ref
         self.Id_ref = Id_ref
         self.Iq_ref = Iq_ref
@@ -181,8 +177,8 @@ class OutElec(FrozenClass):
             OutElec_str += "parent = None " + linesep
         else:
             OutElec_str += "parent = " + str(type(self.parent)) + " object" + linesep
-        OutElec_str += "time = " + str(self.time) + linesep + linesep
-        OutElec_str += "angle = " + str(self.angle) + linesep + linesep
+        OutElec_str += "Time = " + str(self.Time) + linesep + linesep
+        OutElec_str += "Angle = " + str(self.Angle) + linesep + linesep
         OutElec_str += "Is = " + str(self.Is) + linesep + linesep
         OutElec_str += "Ir = " + str(self.Ir) + linesep + linesep
         OutElec_str += (
@@ -197,7 +193,6 @@ class OutElec(FrozenClass):
             "angle_rotor_initial = " + str(self.angle_rotor_initial) + linesep
         )
         OutElec_str += 'logger_name = "' + str(self.logger_name) + '"' + linesep
-        OutElec_str += "mmf_unit = " + str(self.mmf_unit) + linesep + linesep
         OutElec_str += "Tem_av_ref = " + str(self.Tem_av_ref) + linesep
         OutElec_str += "Id_ref = " + str(self.Id_ref) + linesep
         OutElec_str += "Iq_ref = " + str(self.Iq_ref) + linesep
@@ -214,9 +209,9 @@ class OutElec(FrozenClass):
 
         if type(other) != type(self):
             return False
-        if other.time != self.time:
+        if other.Time != self.Time:
             return False
-        if other.angle != self.angle:
+        if other.Angle != self.Angle:
             return False
         if other.Is != self.Is:
             return False
@@ -230,8 +225,6 @@ class OutElec(FrozenClass):
             return False
         if other.logger_name != self.logger_name:
             return False
-        if other.mmf_unit != self.mmf_unit:
-            return False
         if other.Tem_av_ref != self.Tem_av_ref:
             return False
         if other.Id_ref != self.Id_ref:
@@ -256,14 +249,14 @@ class OutElec(FrozenClass):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
         OutElec_dict = dict()
-        if self.time is None:
-            OutElec_dict["time"] = None
+        if self.Time is None:
+            OutElec_dict["Time"] = None
         else:
-            OutElec_dict["time"] = self.time.as_dict()
-        if self.angle is None:
-            OutElec_dict["angle"] = None
+            OutElec_dict["Time"] = self.Time.as_dict()
+        if self.Angle is None:
+            OutElec_dict["Angle"] = None
         else:
-            OutElec_dict["angle"] = self.angle.as_dict()
+            OutElec_dict["Angle"] = self.Angle.as_dict()
         if self.Is is None:
             OutElec_dict["Is"] = None
         else:
@@ -279,10 +272,6 @@ class OutElec(FrozenClass):
         OutElec_dict["N0"] = self.N0
         OutElec_dict["angle_rotor_initial"] = self.angle_rotor_initial
         OutElec_dict["logger_name"] = self.logger_name
-        if self.mmf_unit is None:
-            OutElec_dict["mmf_unit"] = None
-        else:
-            OutElec_dict["mmf_unit"] = self.mmf_unit.as_dict()
         OutElec_dict["Tem_av_ref"] = self.Tem_av_ref
         OutElec_dict["Id_ref"] = self.Id_ref
         OutElec_dict["Iq_ref"] = self.Iq_ref
@@ -302,15 +291,14 @@ class OutElec(FrozenClass):
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
-        self.time = None
-        self.angle = None
+        self.Time = None
+        self.Angle = None
         self.Is = None
         self.Ir = None
         self.angle_rotor = None
         self.N0 = None
         self.angle_rotor_initial = None
         self.logger_name = None
-        self.mmf_unit = None
         self.Tem_av_ref = None
         self.Id_ref = None
         self.Iq_ref = None
@@ -321,55 +309,55 @@ class OutElec(FrozenClass):
         self.Pem_av_ref = None
         self.Us = None
 
-    def _get_time(self):
-        """getter of time"""
-        return self._time
+    def _get_Time(self):
+        """getter of Time"""
+        return self._Time
 
-    def _set_time(self, value):
-        """setter of time"""
+    def _set_Time(self, value):
+        """setter of Time"""
         if isinstance(value, str):  # Load from file
             value = load_init_dict(value)[1]
         if isinstance(value, dict) and "__class__" in value:
             class_obj = import_class(
-                "SciDataTool.Classes", value.get("__class__"), "time"
+                "SciDataTool.Classes", value.get("__class__"), "Time"
             )
             value = class_obj(init_dict=value)
         elif type(value) is int and value == -1:  # Default constructor
             value = Data()
-        check_var("time", value, "Data")
-        self._time = value
+        check_var("Time", value, "Data")
+        self._Time = value
 
-    time = property(
-        fget=_get_time,
-        fset=_set_time,
-        doc=u"""Electrical time vector (no symmetry)
+    Time = property(
+        fget=_get_Time,
+        fset=_set_Time,
+        doc=u"""Electrical time Data object
 
         :Type: SciDataTool.Classes.DataND.Data
         """,
     )
 
-    def _get_angle(self):
-        """getter of angle"""
-        return self._angle
+    def _get_Angle(self):
+        """getter of Angle"""
+        return self._Angle
 
-    def _set_angle(self, value):
-        """setter of angle"""
+    def _set_Angle(self, value):
+        """setter of Angle"""
         if isinstance(value, str):  # Load from file
             value = load_init_dict(value)[1]
         if isinstance(value, dict) and "__class__" in value:
             class_obj = import_class(
-                "SciDataTool.Classes", value.get("__class__"), "angle"
+                "SciDataTool.Classes", value.get("__class__"), "Angle"
             )
             value = class_obj(init_dict=value)
         elif type(value) is int and value == -1:  # Default constructor
             value = Data()
-        check_var("angle", value, "Data")
-        self._angle = value
+        check_var("Angle", value, "Data")
+        self._Angle = value
 
-    angle = property(
-        fget=_get_angle,
-        fset=_set_angle,
-        doc=u"""Electrical position vector (no symmetry)
+    Angle = property(
+        fget=_get_Angle,
+        fset=_set_Angle,
+        doc=u"""Electrical position Data object
 
         :Type: SciDataTool.Classes.DataND.Data
         """,
@@ -508,33 +496,6 @@ class OutElec(FrozenClass):
         """,
     )
 
-    def _get_mmf_unit(self):
-        """getter of mmf_unit"""
-        return self._mmf_unit
-
-    def _set_mmf_unit(self, value):
-        """setter of mmf_unit"""
-        if isinstance(value, str):  # Load from file
-            value = load_init_dict(value)[1]
-        if isinstance(value, dict) and "__class__" in value:
-            class_obj = import_class(
-                "SciDataTool.Classes", value.get("__class__"), "mmf_unit"
-            )
-            value = class_obj(init_dict=value)
-        elif type(value) is int and value == -1:  # Default constructor
-            value = DataND()
-        check_var("mmf_unit", value, "DataND")
-        self._mmf_unit = value
-
-    mmf_unit = property(
-        fget=_get_mmf_unit,
-        fset=_set_mmf_unit,
-        doc=u"""Unit magnetomotive force
-
-        :Type: SciDataTool.Classes.DataND.DataND
-        """,
-    )
-
     def _get_Tem_av_ref(self):
         """getter of Tem_av_ref"""
         return self._Tem_av_ref
@@ -565,7 +526,7 @@ class OutElec(FrozenClass):
     Id_ref = property(
         fget=_get_Id_ref,
         fset=_set_Id_ref,
-        doc=u"""d-axis current magnitude
+        doc=u"""Electrical time vector (no symmetry)
 
         :Type: float
         """,
