@@ -9,6 +9,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
+from ..Functions.copy import copy
+from ..Functions.load import load_init_dict
+from ..Functions.Load.import_class import import_class
 from ._frozen import FrozenClass
 
 # Import all class method
@@ -23,6 +26,7 @@ from ._check import InitUnKnowClassError
 from .Machine import Machine
 from .Input import Input
 from .VarSimu import VarSimu
+from .Post import Post
 
 
 class Simulation(FrozenClass):
@@ -39,15 +43,9 @@ class Simulation(FrozenClass):
         )
     else:
         run = run
-    # save method is available in all object
+    # save and copy methods are available in all object
     save = save
-
-    # generic copy method
-    def copy(self):
-        """Return a copy of the class
-        """
-        return type(self)(init_dict=self.as_dict())
-
+    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -59,39 +57,24 @@ class Simulation(FrozenClass):
         input=-1,
         logger_name="Pyleecan.Simulation",
         var_simu=None,
+        postproc_list=-1,
+        index=None,
+        path_result=None,
         init_dict=None,
         init_str=None,
     ):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
-            for Matrix, None will initialise the property with an empty Matrix
-            for pyleecan type, None will call the default constructor
-        - __init__ (init_dict = d) d must be a dictionnary with every properties as keys
+            for pyleecan type, -1 will call the default constructor
+        - __init__ (init_dict = d) d must be a dictionnary with property names as keys
         - __init__ (init_str = s) s must be a string
         s is the file path to load
 
         ndarray or list can be given for Vector and Matrix
         object or dict can be given for pyleecan Object"""
 
-        if machine == -1:
-            machine = Machine()
-        if input == -1:
-            input = Input()
-        if var_simu == -1:
-            var_simu = VarSimu()
-        if init_str is not None:  # Initialisation by str
-            from ..Functions.load import load
-
-            assert type(init_str) is str
-            # load the object from a file
-            obj = load(init_str)
-            assert type(obj) is type(self)
-            name = obj.name
-            desc = obj.desc
-            machine = obj.machine
-            input = obj.input
-            logger_name = obj.logger_name
-            var_simu = obj.var_simu
+        if init_str is not None:  # Load from a file
+            init_dict = load_init_dict(init_str)[1]
         if init_dict is not None:  # Initialisation by dict
             assert type(init_dict) is dict
             # Overwrite default value with init_dict content
@@ -107,128 +90,29 @@ class Simulation(FrozenClass):
                 logger_name = init_dict["logger_name"]
             if "var_simu" in list(init_dict.keys()):
                 var_simu = init_dict["var_simu"]
-        # Initialisation by argument
+            if "postproc_list" in list(init_dict.keys()):
+                postproc_list = init_dict["postproc_list"]
+            if "index" in list(init_dict.keys()):
+                index = init_dict["index"]
+            if "path_result" in list(init_dict.keys()):
+                path_result = init_dict["path_result"]
+        # Set the properties (value check and convertion are done in setter)
         self.parent = None
         self.name = name
         self.desc = desc
-        # machine can be None, a Machine object or a dict
-        if isinstance(machine, dict):
-            # Check that the type is correct (including daughter)
-            class_name = machine.get("__class__")
-            if class_name not in [
-                "Machine",
-                "MachineAsync",
-                "MachineDFIM",
-                "MachineIPMSM",
-                "MachineSCIM",
-                "MachineSIPMSM",
-                "MachineSRM",
-                "MachineSyRM",
-                "MachineSync",
-                "MachineUD",
-                "MachineWRSM",
-            ]:
-                raise InitUnKnowClassError(
-                    "Unknow class name " + class_name + " in init_dict for machine"
-                )
-            # Dynamic import to call the correct constructor
-            module = __import__("pyleecan.Classes." + class_name, fromlist=[class_name])
-            class_obj = getattr(module, class_name)
-            self.machine = class_obj(init_dict=machine)
-        elif isinstance(machine, str):
-            from ..Functions.load import load
-
-            machine = load(machine)
-            # Check that the type is correct (including daughter)
-            class_name = machine.__class__.__name__
-            if class_name not in [
-                "Machine",
-                "MachineAsync",
-                "MachineDFIM",
-                "MachineIPMSM",
-                "MachineSCIM",
-                "MachineSIPMSM",
-                "MachineSRM",
-                "MachineSyRM",
-                "MachineSync",
-                "MachineUD",
-                "MachineWRSM",
-            ]:
-                raise InitUnKnowClassError(
-                    "Unknow class name " + class_name + " in init_dict for machine"
-                )
-            self.machine = machine
-        else:
-            self.machine = machine
-        # input can be None, a Input object or a dict
-        if isinstance(input, dict):
-            # Check that the type is correct (including daughter)
-            class_name = input.get("__class__")
-            if class_name not in [
-                "Input",
-                "InputCurrent",
-                "InputElec",
-                "InputFlux",
-                "InputForce",
-            ]:
-                raise InitUnKnowClassError(
-                    "Unknow class name " + class_name + " in init_dict for input"
-                )
-            # Dynamic import to call the correct constructor
-            module = __import__("pyleecan.Classes." + class_name, fromlist=[class_name])
-            class_obj = getattr(module, class_name)
-            self.input = class_obj(init_dict=input)
-        elif isinstance(input, str):
-            from ..Functions.load import load
-
-            input = load(input)
-            # Check that the type is correct (including daughter)
-            class_name = input.__class__.__name__
-            if class_name not in [
-                "Input",
-                "InputCurrent",
-                "InputElec",
-                "InputFlux",
-                "InputForce",
-            ]:
-                raise InitUnKnowClassError(
-                    "Unknow class name " + class_name + " in init_dict for input"
-                )
-            self.input = input
-        else:
-            self.input = input
+        self.machine = machine
+        self.input = input
         self.logger_name = logger_name
-        # var_simu can be None, a VarSimu object or a dict
-        if isinstance(var_simu, dict):
-            # Check that the type is correct (including daughter)
-            class_name = var_simu.get("__class__")
-            if class_name not in ["VarSimu", "VarLoad", "VarLoadCurrent", "VarParam"]:
-                raise InitUnKnowClassError(
-                    "Unknow class name " + class_name + " in init_dict for var_simu"
-                )
-            # Dynamic import to call the correct constructor
-            module = __import__("pyleecan.Classes." + class_name, fromlist=[class_name])
-            class_obj = getattr(module, class_name)
-            self.var_simu = class_obj(init_dict=var_simu)
-        elif isinstance(var_simu, str):
-            from ..Functions.load import load
-
-            var_simu = load(var_simu)
-            # Check that the type is correct (including daughter)
-            class_name = var_simu.__class__.__name__
-            if class_name not in ["VarSimu", "VarLoad", "VarLoadCurrent", "VarParam"]:
-                raise InitUnKnowClassError(
-                    "Unknow class name " + class_name + " in init_dict for var_simu"
-                )
-            self.var_simu = var_simu
-        else:
-            self.var_simu = var_simu
+        self.var_simu = var_simu
+        self.postproc_list = postproc_list
+        self.index = index
+        self.path_result = path_result
 
         # The class is frozen, for now it's impossible to add new properties
         self._freeze()
 
     def __str__(self):
-        """Convert this objet in a readeable string (for print)"""
+        """Convert this object in a readeable string (for print)"""
 
         Simulation_str = ""
         if self.parent is None:
@@ -253,6 +137,18 @@ class Simulation(FrozenClass):
             Simulation_str += "var_simu = " + tmp
         else:
             Simulation_str += "var_simu = None" + linesep + linesep
+        if len(self.postproc_list) == 0:
+            Simulation_str += "postproc_list = []" + linesep
+        for ii in range(len(self.postproc_list)):
+            tmp = (
+                self.postproc_list[ii].__str__().replace(linesep, linesep + "\t")
+                + linesep
+            )
+            Simulation_str += (
+                "postproc_list[" + str(ii) + "] =" + tmp + linesep + linesep
+            )
+        Simulation_str += "index = " + str(self.index) + linesep
+        Simulation_str += 'path_result = "' + str(self.path_result) + '"' + linesep
         return Simulation_str
 
     def __eq__(self, other):
@@ -272,11 +168,16 @@ class Simulation(FrozenClass):
             return False
         if other.var_simu != self.var_simu:
             return False
+        if other.postproc_list != self.postproc_list:
+            return False
+        if other.index != self.index:
+            return False
+        if other.path_result != self.path_result:
+            return False
         return True
 
     def as_dict(self):
-        """Convert this objet in a json seriable dict (can be use in __init__)
-        """
+        """Convert this object in a json seriable dict (can be use in __init__)"""
 
         Simulation_dict = dict()
         Simulation_dict["name"] = self.name
@@ -294,7 +195,15 @@ class Simulation(FrozenClass):
             Simulation_dict["var_simu"] = None
         else:
             Simulation_dict["var_simu"] = self.var_simu.as_dict()
-        # The class name is added to the dict fordeserialisation purpose
+        if self.postproc_list is None:
+            Simulation_dict["postproc_list"] = None
+        else:
+            Simulation_dict["postproc_list"] = list()
+            for obj in self.postproc_list:
+                Simulation_dict["postproc_list"].append(obj.as_dict())
+        Simulation_dict["index"] = self.index
+        Simulation_dict["path_result"] = self.path_result
+        # The class name is added to the dict for deserialisation purpose
         Simulation_dict["__class__"] = "Simulation"
         return Simulation_dict
 
@@ -310,6 +219,10 @@ class Simulation(FrozenClass):
         self.logger_name = None
         if self.var_simu is not None:
             self.var_simu._set_None()
+        for obj in self.postproc_list:
+            obj._set_None()
+        self.index = None
+        self.path_result = None
 
     def _get_name(self):
         """getter of name"""
@@ -353,6 +266,15 @@ class Simulation(FrozenClass):
 
     def _set_machine(self, value):
         """setter of machine"""
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class(
+                "pyleecan.Classes", value.get("__class__"), "machine"
+            )
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = Machine()
         check_var("machine", value, "Machine")
         self._machine = value
 
@@ -374,6 +296,15 @@ class Simulation(FrozenClass):
 
     def _set_input(self, value):
         """setter of input"""
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class(
+                "pyleecan.Classes", value.get("__class__"), "input"
+            )
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = Input()
         check_var("input", value, "Input")
         self._input = value
 
@@ -413,6 +344,15 @@ class Simulation(FrozenClass):
 
     def _set_var_simu(self, value):
         """setter of var_simu"""
+        if isinstance(value, str):  # Load from file
+            value = load_init_dict(value)[1]
+        if isinstance(value, dict) and "__class__" in value:
+            class_obj = import_class(
+                "pyleecan.Classes", value.get("__class__"), "var_simu"
+            )
+            value = class_obj(init_dict=value)
+        elif type(value) is int and value == -1:  # Default constructor
+            value = VarSimu()
         check_var("var_simu", value, "VarSimu")
         self._var_simu = value
 
@@ -427,3 +367,71 @@ class Simulation(FrozenClass):
         :Type: VarSimu
         """,
     )
+
+    def _get_postproc_list(self):
+        """getter of postproc_list"""
+        if self._postproc_list is not None:
+            for obj in self._postproc_list:
+                if obj is not None:
+                    obj.parent = self
+        return self._postproc_list
+
+    def _set_postproc_list(self, value):
+        """setter of postproc_list"""
+        if type(value) is list:
+            for ii, obj in enumerate(value):
+                if type(obj) is dict:
+                    class_obj = import_class(
+                        "pyleecan.Classes", obj.get("__class__"), "postproc_list"
+                    )
+                    value[ii] = class_obj(init_dict=obj)
+        if value == -1:
+            value = list()
+        check_var("postproc_list", value, "[Post]")
+        self._postproc_list = value
+
+    postproc_list = property(
+        fget=_get_postproc_list,
+        fset=_set_postproc_list,
+        doc=u"""List of postprocessings to run on Output after the simulation
+
+        :Type: [Post]
+        """,
+    )
+
+    def _get_index(self):
+        """getter of index"""
+        return self._index
+
+    def _set_index(self, value):
+        """setter of index"""
+        check_var("index", value, "int", Vmin=0)
+        self._index = value
+
+    index = property(
+        fget=_get_index,
+        fset=_set_index,
+        doc=u"""Index of the simulation (if part of a multi-simulation)
+
+        :Type: int
+        :min: 0
+        """,
+    )
+
+    def _get_path_result(self):
+        """getter of path_result"""
+        return self._path_result
+
+    def _set_path_result(self, value):
+        """setter of path_result"""
+        check_var("path_result", value, "str")
+        self._path_result = value
+
+    path_result = property(
+        fget=_get_path_result,
+        fset=_set_path_result,
+        doc=u"""Path to the Result folder to use (None to use default one)
+
+        :Type: str
+        """,
+    )
