@@ -9,6 +9,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
+from ..Functions.copy import copy
+from ..Functions.load import load_init_dict
+from ..Functions.Load.import_class import import_class
 from .Slot import Slot
 
 # Import all class method
@@ -38,42 +41,27 @@ class SlotUD(Slot):
         )
     else:
         build_geometry = build_geometry
-    # save method is available in all object
+    # save and copy methods are available in all object
     save = save
-
-    # generic copy method
-    def copy(self):
-        """Return a copy of the class
-        """
-        return type(self)(init_dict=self.as_dict())
-
+    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
     def __init__(
-        self, point_list=[], is_sym=False, Zs=36, init_dict=None, init_str=None
+        self, point_list=-1, is_sym=False, Zs=36, init_dict=None, init_str=None
     ):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
-            for Matrix, None will initialise the property with an empty Matrix
-            for pyleecan type, None will call the default constructor
-        - __init__ (init_dict = d) d must be a dictionnary with every properties as keys
+            for pyleecan type, -1 will call the default constructor
+        - __init__ (init_dict = d) d must be a dictionnary with property names as keys
         - __init__ (init_str = s) s must be a string
         s is the file path to load
 
         ndarray or list can be given for Vector and Matrix
         object or dict can be given for pyleecan Object"""
 
-        if init_str is not None:  # Initialisation by str
-            from ..Functions.load import load
-
-            assert type(init_str) is str
-            # load the object from a file
-            obj = load(init_str)
-            assert type(obj) is type(self)
-            point_list = obj.point_list
-            is_sym = obj.is_sym
-            Zs = obj.Zs
+        if init_str is not None:  # Load from a file
+            init_dict = load_init_dict(init_str)[1]
         if init_dict is not None:  # Initialisation by dict
             assert type(init_dict) is dict
             # Overwrite default value with init_dict content
@@ -83,9 +71,7 @@ class SlotUD(Slot):
                 is_sym = init_dict["is_sym"]
             if "Zs" in list(init_dict.keys()):
                 Zs = init_dict["Zs"]
-        # Initialisation by argument
-        if point_list == -1:
-            point_list = []
+        # Set the properties (value check and convertion are done in setter)
         self.point_list = point_list
         self.is_sym = is_sym
         # Call Slot init
@@ -94,7 +80,7 @@ class SlotUD(Slot):
         # add new properties
 
     def __str__(self):
-        """Convert this objet in a readeable string (for print)"""
+        """Convert this object in a readeable string (for print)"""
 
         SlotUD_str = ""
         # Get the properties inherited from Slot
@@ -124,14 +110,15 @@ class SlotUD(Slot):
         return True
 
     def as_dict(self):
-        """Convert this objet in a json seriable dict (can be use in __init__)
-        """
+        """Convert this object in a json seriable dict (can be use in __init__)"""
 
         # Get the properties inherited from Slot
         SlotUD_dict = super(SlotUD, self).as_dict()
-        SlotUD_dict["point_list"] = self.point_list
+        SlotUD_dict["point_list"] = (
+            self.point_list.copy() if self.point_list is not None else None
+        )
         SlotUD_dict["is_sym"] = self.is_sym
-        # The class name is added to the dict fordeserialisation purpose
+        # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         SlotUD_dict["__class__"] = "SlotUD"
         return SlotUD_dict
@@ -150,6 +137,8 @@ class SlotUD(Slot):
 
     def _set_point_list(self, value):
         """setter of point_list"""
+        if type(value) is int and value == -1:
+            value = list()
         check_var("point_list", value, "list")
         self._point_list = value
 
