@@ -9,6 +9,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
+from ..Functions.copy import copy
+from ..Functions.load import load_init_dict
+from ..Functions.Load.import_class import import_class
 from .Slot import Slot
 
 # Import all class method
@@ -38,6 +41,11 @@ try:
 except ImportError as error:
     plot_wind = error
 
+try:
+    from ..Methods.Slot.SlotWind.build_geometry_wind import build_geometry_wind
+except ImportError as error:
+    build_geometry_wind = error
+
 
 from ._check import InitUnKnowClassError
 
@@ -105,51 +113,50 @@ class SlotWind(Slot):
         )
     else:
         plot_wind = plot_wind
-    # save method is available in all object
+    # cf Methods.Slot.SlotWind.build_geometry_wind
+    if isinstance(build_geometry_wind, ImportError):
+        build_geometry_wind = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use SlotWind method build_geometry_wind: "
+                    + str(build_geometry_wind)
+                )
+            )
+        )
+    else:
+        build_geometry_wind = build_geometry_wind
+    # save and copy methods are available in all object
     save = save
-
-    # generic copy method
-    def copy(self):
-        """Return a copy of the class
-        """
-        return type(self)(init_dict=self.as_dict())
-
+    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
     def __init__(self, Zs=36, init_dict=None, init_str=None):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
-            for Matrix, None will initialise the property with an empty Matrix
-            for pyleecan type, None will call the default constructor
-        - __init__ (init_dict = d) d must be a dictionnary with every properties as keys
+            for pyleecan type, -1 will call the default constructor
+        - __init__ (init_dict = d) d must be a dictionnary with property names as keys
         - __init__ (init_str = s) s must be a string
         s is the file path to load
 
         ndarray or list can be given for Vector and Matrix
         object or dict can be given for pyleecan Object"""
 
-        if init_str is not None:  # Initialisation by str
-            from ..Functions.load import load
-
-            assert type(init_str) is str
-            # load the object from a file
-            obj = load(init_str)
-            assert type(obj) is type(self)
-            Zs = obj.Zs
+        if init_str is not None:  # Load from a file
+            init_dict = load_init_dict(init_str)[1]
         if init_dict is not None:  # Initialisation by dict
             assert type(init_dict) is dict
             # Overwrite default value with init_dict content
             if "Zs" in list(init_dict.keys()):
                 Zs = init_dict["Zs"]
-        # Initialisation by argument
+        # Set the properties (value check and convertion are done in setter)
         # Call Slot init
         super(SlotWind, self).__init__(Zs=Zs)
         # The class is frozen (in Slot init), for now it's impossible to
         # add new properties
 
     def __str__(self):
-        """Convert this objet in a readeable string (for print)"""
+        """Convert this object in a readeable string (for print)"""
 
         SlotWind_str = ""
         # Get the properties inherited from Slot
@@ -168,12 +175,11 @@ class SlotWind(Slot):
         return True
 
     def as_dict(self):
-        """Convert this objet in a json seriable dict (can be use in __init__)
-        """
+        """Convert this object in a json seriable dict (can be use in __init__)"""
 
         # Get the properties inherited from Slot
         SlotWind_dict = super(SlotWind, self).as_dict()
-        # The class name is added to the dict fordeserialisation purpose
+        # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         SlotWind_dict["__class__"] = "SlotWind"
         return SlotWind_dict
