@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
 import matplotlib.pyplot as plt
-from .plot_A_2D import plot_A_2D
-from .plot_A_3D import plot_A_3D
+from .plot_2D import plot_2D
+from .plot_3D import plot_3D
 from ...definitions import config_dict
 from numpy import meshgrid, max as np_max
 
@@ -78,8 +78,8 @@ def plot_A_time_space(
     else:
         results = data.get_along("time", "angle", unit=unit, is_norm=is_norm)
     angle = results["angle"]
-    if is_deg and round(max(angle) / 6) % 5 == 0:
-        xticks = [i * round(max(angle) / 6) for i in range(7)]
+    if is_deg and round(np_max(angle) / 6) % 5 == 0:
+        xticks = [i * round(np_max(angle) / 6) for i in range(7)]
     else:
         xticks = None
     time = results["time"]
@@ -87,13 +87,12 @@ def plot_A_time_space(
     angle_map, time_map = meshgrid(angle, time)
     if z_max is None:
         z_max = np_max(A_t_s)
-    plot_A_3D(
+    plot_3D(
         angle_map,
         time_map,
         A_t_s,
         z_max=z_max,
         z_min=-z_max,
-        colormap=colormap,
         xlabel=xlabel,
         ylabel=ylabel,
         zlabel=zlabel,
@@ -115,7 +114,7 @@ def plot_A_time_space(
     time = results["time"]
     Ydata = [results[data.symbol]]
     # Plot the original graph
-    plot_A_2D(
+    plot_2D(
         time,
         Ydata,
         fig=fig,
@@ -137,7 +136,7 @@ def plot_A_time_space(
     angle = results["angle"]
     Ydata = [results[data.symbol]]
     # Plot the original graph
-    plot_A_2D(
+    plot_2D(
         angle,
         Ydata,
         fig=fig,
@@ -180,14 +179,14 @@ def plot_A_time_space(
     else:
         xticks = None
 
-    plot_A_2D(
+    plot_2D(
         freqs,
         Ydata,
         fig=fig,
         subplot_index=3,
         xlabel=xlabel,
         ylabel=ylabel,
-        type="bargraph",
+        type_plot="bargraph",
         xticks=xticks,
         color_list=color_list,
     )
@@ -216,14 +215,14 @@ def plot_A_time_space(
     else:
         xticks = None
 
-    plot_A_2D(
+    plot_2D(
         wavenumber,
         Ydata,
         fig=fig,
         subplot_index=5,
         xlabel=xlabel,
         ylabel=ylabel,
-        type="bargraph",
+        type_plot="bargraph",
         xticks=xticks,
         color_list=color_list,
     )
@@ -236,4 +235,6 @@ def plot_A_time_space(
 
     if save_path is not None:
         fig.savefig(save_path)
-        plt.close()
+        # plt.close()
+
+    fig.show()
