@@ -1,18 +1,16 @@
-from PyQt5.QtCore import QSize
-from PyQt5.QtWidgets import QGroupBox, QLabel, QVBoxLayout, QWidget
+from PySide2.QtCore import QSize
+from PySide2.QtWidgets import QGroupBox, QLabel, QVBoxLayout, QWidget
 
 from ......GUI import gui_option
 
 
 class WWSlotOut(QGroupBox):
-    """Setup of QGroupBox for output for Winding Slot
-    """
+    """Setup of QGroupBox for output for Winding Slot"""
 
     def __init__(self, parent=None):
-        """Initialize the widget
-        """
+        """Initialize the widget"""
 
-        QWidget.__init__(self, parent)
+        QGroupBox.__init__(self, parent)
         # Set main widget
         self.setTitle(self.tr("Output"))
         self.setMinimumSize(QSize(200, 0))
