@@ -4,7 +4,7 @@ from ....Classes.MeshMat import MeshMat
 
 
 def plot_mesh(
-    self, label=None, index=None, indices=None, save_path=None, group_names=None,
+    self, label=None, index=None, indices=None, save_path=None, group_names=None
 ):
     """Plot the mesh using pyvista plotter.
 
@@ -24,9 +24,7 @@ def plot_mesh(
     """
     if group_names is not None:
         meshsol_grp = self.get_group(group_names)
-        meshsol_grp.plot_mesh(
-            label, index, indices, save_path, None,
-        )
+        meshsol_grp.plot_mesh(label, index, indices, save_path, None)
     else:
 
         if save_path is None:
@@ -50,7 +48,7 @@ def plot_mesh(
         if isinstance(mesh_obj, MeshMat):
             mesh = mesh_obj.get_mesh_pv(indices=indices)
         else:
-            mesh = mesh_obj.get_mesh(indices=indices)
+            mesh = mesh_obj.get_mesh_pv(indices=indices)
 
         # Configure plot
         if is_pyvistaqt:
