@@ -2,7 +2,8 @@
 
 
 def get_rot_dir(self):
-    """Return the rotation direction
+    """Return the rotation direction of the magnetic field fundamental
+    WARNING: rot_dir = -1 to have positive rotor rotating direction, i.e. rotor position moves towards positive angle
 
     Parameters
     ----------
@@ -11,13 +12,13 @@ def get_rot_dir(self):
 
     Returns
     -------
-    alpha_rotor: numpy.ndarray
-        angular position of the rotor as a function of time (vector) [rad]
+    rot_dir: int
+        Rotation direction of magnetic field fundamental
 
     """
 
     # Already available => Return
-    if self.geo.rot_dir is not None and self.geo.rot_dir.size > 0:
+    if self.geo.rot_dir is not None:
         return self.geo.rot_dir
     else:  # Compute
         rot_dir = self.simu.machine.stator.comp_rot_dir()
