@@ -11,16 +11,37 @@ from ....Functions.FEMM.comp_FEMM_Phi_wind import comp_FEMM_Phi_wind
 from ....Functions.Winding.gen_phase_list import gen_name
 
 
-def solve_FEMM(self, femm, output, sym):
+def solve_FEMM(self, femm, output, sym, axes_dict):
+    """
+    Solve FEMM model to calculate airgap flux density, torque instantaneous/average/ripple values,
+    flux induced in stator windings and flux density, field and permeability maps
+
+    /!\ Any changes in solve_FEMM must be also made in solve_FEMM_parallel
+
+    Parameters
+    ----------
+    self: MagFEMM
+        A MagFEMM object
+    femm: FEMMHandler
+        Object to handle FEMM
+    output: Output
+        An Output object
+    sym: int
+        Spatial symmetry factor
+    axes_dict: {Data}
+        Dict of axes used for magnetic calculation
+    """
 
     # Get time and angular axes
-    Angle_comp, Time_comp = self.get_axes(output)
+    Angle = axes_dict["Angle"]
+    Time = axes_dict["Time"]
+    Time_Tem = axes_dict["Time_Tem"]
 
     # Check if the angular axis is anti-periodic
-    _, is_antiper_a = Angle_comp.get_periodicity()
+    _, is_antiper_a = Angle.get_periodicity()
 
     # Import angular vector from Data object
-    angle = Angle_comp.get_values(
+    angle = Angle.get_values(
         is_oneperiod=self.is_periodicity_a,
         is_antiperiod=is_antiper_a and self.is_periodicity_a,
     )
@@ -28,11 +49,11 @@ def solve_FEMM(self, femm, output, sym):
     # Number of angular steps
     Na_comp = angle.size
 
-    # Check if the angular axis is anti-periodic
-    _, is_antiper_t = Time_comp.get_periodicity()
+    # Check if the time axis is anti-periodic
+    _, is_antiper_t = Time.get_periodicity()
 
     # Number of time steps
-    Nt_comp = Time_comp.get_length(
+    Nt_comp = Time.get_length(
         is_oneperiod=True,
         is_antiperiod=is_antiper_t and self.is_periodicity_t,
     )
@@ -87,6 +108,8 @@ def solve_FEMM(self, femm, output, sym):
 
         # Run the computation
         femm.mi_analyze()
+
+        # Load results
         femm.mi_loadsolution()
 
         # Get the flux result
@@ -141,27 +164,18 @@ def solve_FEMM(self, femm, output, sym):
     Br = roll(Br, roll_id, axis=1)
     Bt = roll(Bt, roll_id, axis=1)
 
-    # Store the results
-    sym_dict = dict()  # Define the periodicity
-    if self.is_periodicity_t:
-        sym_dict.update(Time_comp.symmetries)
-    if self.is_periodicity_a:
-        sym_dict.update(Angle_comp.symmetries)
-
     Br_data = DataTime(
         name="Airgap radial flux density",
         unit="T",
         symbol="B_r",
-        axes=[Time_comp, Angle_comp],
-        symmetries=sym_dict,
+        axes=[Time, Angle],
         values=Br,
     )
     Bt_data = DataTime(
         name="Airgap tangential flux density",
         unit="T",
         symbol="B_t",
-        axes=[Time_comp, Angle_comp],
-        symmetries=sym_dict,
+        axes=[Time, Angle],
         values=Bt,
     )
     output.mag.B = VectorField(
@@ -174,8 +188,7 @@ def solve_FEMM(self, femm, output, sym):
         name="Electromagnetic torque",
         unit="Nm",
         symbol="T_{em}",
-        axes=[Time_comp],
-        symmetries=sym_dict,
+        axes=[Time_Tem],
         values=Tem,
     )
     output.mag.Tem_av = mean(Tem)
@@ -193,15 +206,14 @@ def solve_FEMM(self, femm, output, sym):
         Phase = Data1D(
             name="phase",
             unit="",
-            values=gen_name(qs, is_add_phase=True),
+            values=gen_name(qs),
             is_components=True,
         )
         output.mag.Phi_wind_stator = DataTime(
             name="Stator Winding Flux",
             unit="Wb",
             symbol="Phi_{wind}",
-            axes=[Time_comp, Phase],
-            symmetries=sym_dict,
+            axes=[Time, Phase],
             values=Phi_wind_stator,
         )
 
@@ -209,7 +221,7 @@ def solve_FEMM(self, femm, output, sym):
 
     if self.is_get_mesh:
         output.mag.meshsolution = self.build_meshsolution(
-            Nt_comp, meshFEMM, Time_comp, B_elem, H_elem, mu_elem, groups
+            Nt_comp, meshFEMM, Time, B_elem, H_elem, mu_elem, groups
         )
 
     if self.is_save_FEA:
