@@ -17,5 +17,10 @@ def set_reused_data(self, simu, output):
     """
 
     if self.is_reuse_femm_file and isinstance(simu.mag, MagFEMM):
+        self.get_logger().info(
+            "VarSimu: Using same FEMM file for all simulation ("
+            + output.mag.FEMM_dict["path_save"]
+            + ")"
+        )
         simu.mag.import_file = output.mag.FEMM_dict["path_save"]
         simu.mag.FEMM_dict = output.mag.FEMM_dict
