@@ -5,6 +5,7 @@ from matplotlib.pyplot import axis, legend
 
 from ....Functions.init_fig import init_fig
 from ....definitions import config_dict
+from ....Methods import ParentMissingError
 
 MAGNET_COLOR = config_dict["PLOT"]["COLOR_DICT"]["MAGNET_COLOR"]
 
@@ -52,9 +53,12 @@ def plot(self, fig=None, display_magnet=True):
 
     # Axis Setup
     axis("equal")
-    Lim = self.get_Rbo() * 1.2
-    axes.set_xlim(-Lim, Lim)
-    axes.set_ylim(-Lim, Lim)
+    try:
+        Lim = self.get_Rbo() * 1.2
+        axes.set_xlim(-Lim, Lim)
+        axes.set_ylim(-Lim, Lim)
+    except ParentMissingError:
+        pass
 
     if display_magnet and "Magnet" in [surf.label for surf in surf_hole]:
         patch_leg.append(Patch(color=MAGNET_COLOR))
